==> datadog_api_client-1.10.0-py3-none-any.whl: datadog_api_client/v1/model/synthetics_assertion_type.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ApiTypeError,
    ModelSimple,
    cached_property,
)


class SyntheticsAssertionType(ModelSimple):
    allowed_values = {
        "value": {
            "BODY": "body",
            "HEADER": "header",
            "STATUS_CODE": "statusCode",
            "CERTIFICATE": "certificate",
            "RESPONSE_TIME": "responseTime",
            "PROPERTY": "property",
            "RECORD_EVERY": "recordEvery",
            "RECORD_SOME": "recordSome",
            "TLS_VERSION": "tlsVersion",
            "MIN_TLS_VERSION": "minTlsVersion",
            "LATENCY": "latency",
            "PACKET_LOSS_PERCENTAGE": "packetLossPercentage",
            "PACKETS_RECEIVED": "packetsReceived",
            "NETWORK_HOP": "networkHop",
            "RECEIVED_MESSAGE": "receivedMessage",
        },
    }

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "value": (str,),
        }

    def __init__(self, *args, **kwargs):
        """
        Type of the assertion.

        Note that value can be passed either in args or in kwargs, but not in both.

        :param value: Must be one of ["body", "header", "statusCode", "certificate", "responseTime", "property", "recordEvery", "recordSome", "tlsVersion", "minTlsVersion", "latency", "packetLossPercentage", "packetsReceived", "networkHop", "receivedMessage"].
        :type value: str
        """
        super().__init__(kwargs)

        if "value" in kwargs:
            value = kwargs.pop("value")
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            raise ApiTypeError(
                "value is required, but not passed in args or kwargs and doesn't have default",
                path_to_item=self._path_to_item,
                valid_classes=(self.__class__,),
            )

        self._check_pos_args(args)

        self.value = value

        self._check_kw_args(kwargs)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""
        return cls(*args, **kwargs)

==> datadog_api_client-2.0.0-py3-none-any.whl: datadog_api_client/v1/model/synthetics_assertion_type.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ApiTypeError,
    ModelSimple,
    cached_property,
)


class SyntheticsAssertionType(ModelSimple):

    allowed_values = {
        "value": {
            "BODY": "body",
            "HEADER": "header",
            "STATUS_CODE": "statusCode",
            "CERTIFICATE": "certificate",
            "RESPONSE_TIME": "responseTime",
            "PROPERTY": "property",
            "RECORD_EVERY": "recordEvery",
            "RECORD_SOME": "recordSome",
            "TLS_VERSION": "tlsVersion",
            "MIN_TLS_VERSION": "minTlsVersion",
            "LATENCY": "latency",
            "PACKET_LOSS_PERCENTAGE": "packetLossPercentage",
            "PACKETS_RECEIVED": "packetsReceived",
            "NETWORK_HOP": "networkHop",
            "RECEIVED_MESSAGE": "receivedMessage",
            "GRPC_HEALTHCHECK_STATUS": "grpcHealthcheckStatus",
            "CONNECTION": "connection",
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }

    def __init__(self, *args, **kwargs):
        """
        Type of the assertion.

        Note that value can be passed either in args or in kwargs, but not in both.

        :param value: Must be one of ["body", "header", "statusCode", "certificate", "responseTime", "property", "recordEvery", "recordSome", "tlsVersion", "minTlsVersion", "latency", "packetLossPercentage", "packetsReceived", "networkHop", "receivedMessage", "grpcHealthcheckStatus", "connection"].
        :type value: str
        """
        super().__init__(kwargs)

        if "value" in kwargs:
            value = kwargs.pop("value")
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            raise ApiTypeError(
                "value is required, but not passed in args or kwargs and doesn't have default",
                path_to_item=self._path_to_item,
                valid_classes=(self.__class__,),
            )

        self._check_pos_args(args)

        self.value = value

        self._check_kw_args(kwargs)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""
        return cls(*args, **kwargs)
